@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2024, by Samuel Williams.
+# Copyright, 2020-2026, by Samuel Williams.
 
-require_relative 'client'
+require_relative "client"
 
-require 'console/logger'
+require "console"
 
 module Async
 	module Container
@@ -24,8 +24,8 @@ module Async
 				end
 				
 				# Send a message to the console.
-				def send(level: :debug, **message)
-					@logger.send(level, self) {message}
+				def send(level: :info, **message)
+					@logger.public_send(level, self){message}
 				end
 				
 				# Send an error message to the console.
